@@ -6,23 +6,56 @@ from collections import defaultdict
 from importlib import resources
 
 from .base_rust_api import BaseRustSocket
-from .structures import RustInfo, RustMap, RustMarker, RustChatMessage, RustTeamInfo, RustEntityInfo, RustContents, \
-    RustItem
+from .structures import (
+    RustInfo,
+    RustMap,
+    RustMarker,
+    RustChatMessage,
+    RustTeamInfo,
+    RustEntityInfo,
+    RustContents,
+    RustItem,
+)
 from .remote.rustplus_pb2 import *
 from .remote import HeartBeat
 from ..commands import CommandOptions
 from ..exceptions import *
-from ..utils import RustTime, format_time, format_coord, convert_marker, convert_monument, translate_id_to_stack, deprecated
+from ..utils import (
+    RustTime,
+    format_time,
+    format_coord,
+    convert_marker,
+    convert_monument,
+    translate_id_to_stack,
+    deprecated,
+)
 
 
 class RustSocket(BaseRustSocket):
-
-    def __init__(self, ip: str = None, port: str = None, steamid: int = None, playertoken: int = None,
-                 command_options: CommandOptions = None, raise_ratelimit_exception: bool = True,
-                 ratelimit_limit: int = 25, ratelimit_refill: int = 3, use_proxy: bool = False) -> None:
-        super().__init__(ip=ip, port=port, steamid=steamid, playertoken=playertoken, command_options=command_options,
-                         raise_ratelimit_exception=raise_ratelimit_exception, ratelimit_limit=ratelimit_limit,
-                         ratelimit_refill=ratelimit_refill, heartbeat=HeartBeat(self), use_proxy=use_proxy)
+    def __init__(
+        self,
+        ip: str = None,
+        port: str = None,
+        steamid: int = None,
+        playerToken: int = None,
+        command_options: CommandOptions = None,
+        raise_ratelimit_exception: bool = True,
+        ratelimit_limit: int = 25,
+        ratelimit_refill: int = 3,
+        use_proxy: bool = False,
+    ) -> None:
+        super().__init__(
+            ip=ip,
+            port=port,
+            steamid=steamid,
+            playerToken=playerToken,
+            command_options=command_options,
+            raise_ratelimit_exception=raise_ratelimit_exception,
+            ratelimit_limit=ratelimit_limit,
+            ratelimit_refill=ratelimit_refill,
+            heartbeat=HeartBeat(self),
+            use_proxy=use_proxy,
+        )
 
     async def get_time(self) -> RustTime:
 
@@ -73,7 +106,9 @@ class RustSocket(BaseRustSocket):
 
         await self.remote.send_message(app_request)
 
-        messages = (await self.remote.get_response(app_request.seq, app_request)).response.teamChat.messages
+        messages = (
+            await self.remote.get_response(app_request.seq, app_request)
+        ).response.teamChat.messages
 
         return [RustChatMessage(message) for message in messages]
 
@@ -101,7 +136,9 @@ class RustSocket(BaseRustSocket):
 
         app_message = await self.remote.get_response(app_request.seq, app_request)
 
-        return [RustMarker(marker) for marker in app_message.response.mapMarkers.markers]
+        return [
+            RustMarker(marker) for marker in app_message.response.mapMarkers.markers
+        ]
 
     async def get_raw_map_data(self) -> RustMap:
 
@@ -116,15 +153,24 @@ class RustSocket(BaseRustSocket):
 
         return RustMap(app_message.response.map)
 
-    async def get_map(self, add_icons: bool = False, add_events: bool = False, add_vending_machines: bool = False,
-                      override_images: dict = None) -> Image:
+    async def get_map(
+        self,
+        add_icons: bool = False,
+        add_events: bool = False,
+        add_vending_machines: bool = False,
+        override_images: dict = None,
+    ) -> Image:
 
         if override_images is None:
             override_images = {}
 
         map_size = int((await self.get_info()).size)
 
-        await self._handle_ratelimit(5 + 1 if [add_icons, add_events, add_vending_machines].count(True) >= 1 else 0)
+        await self._handle_ratelimit(
+            5 + 1
+            if [add_icons, add_events, add_vending_machines].count(True) >= 1
+            else 0
+        )
 
         app_request = self._generate_protobuf()
         app_request.getMap.CopyFrom(AppEmpty())
@@ -157,30 +203,53 @@ class RustSocket(BaseRustSocket):
                         icon = icon.resize((150, 150))
                     if str(monument.token) == "train_tunnel_display_name":
                         icon = icon.resize((100, 125))
-                    game_map.paste(icon, (format_coord(int(monument.x), int(monument.y), map_size)), icon)
+                    game_map.paste(
+                        icon,
+                        (format_coord(int(monument.x), int(monument.y), map_size)),
+                        icon,
+                    )
 
             if add_vending_machines:
-                with resources.path("rustplus.api.icons", "vending_machine.png") as path:
+                with resources.path(
+                    "rustplus.api.icons", "vending_machine.png"
+                ) as path:
                     vending_machine = Image.open(path).convert("RGBA")
                     vending_machine = vending_machine.resize((100, 100))
 
             for marker in map_markers:
                 if add_events:
-                    if marker.type == 2 or marker.type == 4 or marker.type == 5 or marker.type == 6 or marker.type == 8:
+                    if (
+                        marker.type == 2
+                        or marker.type == 4
+                        or marker.type == 5
+                        or marker.type == 6
+                        or marker.type == 8
+                    ):
                         icon = convert_marker(str(marker.type), marker.rotation)
                         if marker.type == 6:
                             x = marker.x
                             y = marker.y
-                            if y > map_size: y = map_size
-                            if y < 0: y = 100
-                            if x > map_size: x = map_size - 75
-                            if x < 0: x = 50
+                            if y > map_size:
+                                y = map_size
+                            if y < 0:
+                                y = 100
+                            if x > map_size:
+                                x = map_size - 75
+                            if x < 0:
+                                x = 50
                             game_map.paste(icon, (int(x), map_size - int(y)), icon)
                         else:
-                            game_map.paste(icon, (format_coord(int(marker.x), int(marker.y), map_size)), icon)
+                            game_map.paste(
+                                icon,
+                                (format_coord(int(marker.x), int(marker.y), map_size)),
+                                icon,
+                            )
                 if add_vending_machines and marker.type == 3:
-                    game_map.paste(vending_machine, (int(marker.x) - 50, map_size - int(marker.y) - 50),
-                                   vending_machine)
+                    game_map.paste(
+                        vending_machine,
+                        (int(marker.x) - 50, map_size - int(marker.y) - 50),
+                        vending_machine,
+                    )
 
         return game_map.resize((2000, 2000), Image.ANTIALIAS)
 
@@ -250,10 +319,19 @@ class RustSocket(BaseRustSocket):
 
     async def get_current_events(self) -> List[RustMarker]:
 
-        return [marker for marker in (await self.get_markers()) if
-                marker.type == 2 or marker.type == 4 or marker.type == 5 or marker.type == 6 or marker.type == 8]
+        return [
+            marker
+            for marker in (await self.get_markers())
+            if marker.type == 2
+            or marker.type == 4
+            or marker.type == 5
+            or marker.type == 6
+            or marker.type == 8
+        ]
 
-    async def get_contents(self, eid: int = None, combine_stacks: bool = False) -> RustContents:
+    async def get_contents(
+        self, eid: int = None, combine_stacks: bool = False
+    ) -> RustContents:
 
         if eid is None:
             raise ValueError("EID cannot be None")
@@ -266,7 +344,14 @@ class RustSocket(BaseRustSocket):
         items = []
 
         for item in returned_data.items:
-            items.append(RustItem(translate_id_to_stack(item.itemId), item.itemId, item.quantity, item.itemIsBlueprint))
+            items.append(
+                RustItem(
+                    translate_id_to_stack(item.itemId),
+                    item.itemId,
+                    item.quantity,
+                    item.itemIsBlueprint,
+                )
+            )
 
         if combine_stacks:
             merged_map = defaultdict(tuple)
@@ -277,15 +362,26 @@ class RustSocket(BaseRustSocket):
                     count = int(data[0]) + int(item.quantity)
                     merged_map[str(item.itemId)] = (count, bool(item.isBlueprint))
                 else:
-                    merged_map[str(item.itemId)] = (int(item.quantity), bool(item.isBlueprint))
+                    merged_map[str(item.itemId)] = (
+                        int(item.quantity),
+                        bool(item.isBlueprint),
+                    )
 
             items = []
             for key in merged_map.keys():
                 items.append(
-                    RustItem(translate_id_to_stack(key), key, int(merged_map[key][0]), bool(merged_map[key][1])))
+                    RustItem(
+                        translate_id_to_stack(key),
+                        key,
+                        int(merged_map[key][0]),
+                        bool(merged_map[key][1]),
+                    )
+                )
 
         return RustContents(difference, bool(returned_data.hasProtection), items)
 
     @deprecated("Use RustSocket#get_contents")
-    async def get_tc_storage_contents(self, eid: int = None, combine_stacks: bool = False) -> RustContents:
+    async def get_tc_storage_contents(
+        self, eid: int = None, combine_stacks: bool = False
+    ) -> RustContents:
         return await self.get_contents(eid=eid, combine_stacks=combine_stacks)
